#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import composition
from .fhirdate import FHIRDate


class CompositionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Composition", js["resourceType"])
        return composition.Composition(js)
    
    def testComposition1(self):
        inst = self.instantiate_from("composition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Composition instance")
        self.implComposition1(inst)
        
        js = inst.as_json()
        self.assertEqual("Composition", js["resourceType"])
        inst2 = composition.Composition(js)
        self.implComposition1(inst2)
    
    def implComposition1(self, inst):
        self.assertEqual(inst.attester[0].mode[0], "legal")
        self.assertEqual(inst.confidentiality, "N")
        self.assertEqual(inst.date.date, FHIRDate("2012-01-04T09:10:14Z").date)
        self.assertEqual(inst.date.as_json(), "2012-01-04T09:10:14Z")
        self.assertEqual(inst.id, "example")
        self.assertEqual(inst.identifier.system, "http://healthintersections.com.au/test")
        self.assertEqual(inst.identifier.value, "1")
        self.assertEqual(inst.section[0].title, "History of present illness")
        self.assertEqual(inst.status, "final")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "11488-4")
        self.assertEqual(inst.type.coding[0].display, "Consult note")
        self.assertEqual(inst.type.coding[0].system, "http://loinc.org")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/HealthcareService) on 2015-07-06.
#  2015, SMART Health IT.


from . import attachment
from . import codeableconcept
from . import contactpoint
from . import domainresource
from . import fhirdate
from . import fhirelement
from . import fhirreference
from . import identifier
from . import period


class HealthcareService(domainresource.DomainResource):
    """ The details of a Healthcare Service available at a location.
    """
    
    resource_name = "HealthcareService"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.appointmentRequired = None
        """ Indicates if an appointment is required for access to this service.
        Type `bool`. """
        
        self.availabilityExceptions = None
        """ A description of Site availability exceptions, e.g., public holiday
        availability. Succinctly describing all possible exceptions to
        normal Site availability as details in the Available Times and Not
        Available Times.
        Type `str`. """
        
        self.availableTime = None
        """ A Collection of times that the Service Site is available.
        List of `HealthcareServiceAvailableTime` items (represented as `dict` in JSON). """
        
        self.characteristic = None
        """ Collection of Characteristics (attributes).
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.comment = None
        """ Any additional description of the service and/or any specific
        issues not covered by the other attributes, which can be displayed
        as further detail under the serviceName.
        Type `str`. """
        
        self.coverageArea = None
        """ The location(s) that this service is available to (not where the
        service is provided).
        List of `FHIRReference` items referencing `Location` (represented as `dict` in JSON). """
        
        self.eligibility = None
        """ Does this service have specific eligibility requirements that need
        to be met in order to use the service.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.eligibilityNote = None
        """ Describes the eligibility conditions for the service.
        Type `str`. """
        
        self.extraDetails = None
        """ Extra details about the service that can't be placed in the other
        fields.
        Type `str`. """
        
        self.identifier = None
        """ External Identifiers for this item.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.location = None
        """ The location where this healthcare service may be provided.
        Type `FHIRReference` referencing `Location` (represented as `dict` in JSON). """
        
        self.notAvailable = None
        """ The HealthcareService is not available during this period of time
        due to the provided reason.
        List of `HealthcareServiceNotAvailable` items (represented as `dict` in JSON). """
        
        self.photo = None
        """ If there is a photo/symbol associated with this HealthcareService,
        it may be included here to facilitate quick identification of the
        service in a list.
        Type `Attachment` (represented as `dict` in JSON). """
        
        self.programName = None
        """ Program Names that can be used to categorize the service.
        List of `str` items. """
        
        self.providedBy = None
        """ The organization that provides this Healthcare Service.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.publicKey = None
        """ The public part of the 'keys' allocated to an Organization by an
        accredited body to support secure exchange of data over the
        internet. To be provided by the Organization, where available.
        Type `str`. """
        
        self.referralMethod = None
        """ Ways that the service accepts referrals.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.serviceCategory = None
        """ Identifies the broad category of service being performed or
        delivered. Selecting a Service Category then determines the list of
        relevant service types that can be selected in the Primary Service
        Type.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.serviceName = None
        """ Further description of the service as it would be presented to a
        consumer while searching.
        Type `str`. """
        
        self.serviceProvisionCode = None
        """ The code(s) that detail the conditions under which the healthcare
        service is available/offered.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.serviceType = None
        """ A specific type of service that may be delivered or performed.
        List of `HealthcareServiceServiceType` items (represented as `dict` in JSON). """
        
        self.telecom = None
        """ List of contacts related to this specific healthcare service. If
        this is empty, then refer to the location's contacts.
        List of `ContactPoint` items (represented as `dict` in JSON). """
        
        super(HealthcareService, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(HealthcareService, self).elementProperties()
        js.extend([
            ("appointmentRequired", "appointmentRequired", bool, False),
            ("availabilityExceptions", "availabilityExceptions", str, False),
            ("availableTime", "availableTime", HealthcareServiceAvailableTime, True),
            ("characteristic", "characteristic", codeableconcept.CodeableConcept, True),
            ("comment", "comment", str, False),
            ("coverageArea", "coverageArea", fhirreference.FHIRReference, True),
            ("eligibility", "eligibility", codeableconcept.CodeableConcept, False),
            ("eligibilityNote", "eligibilityNote", str, False),
            ("extraDetails", "extraDetails", str, False),
            ("identifier", "identifier", identifier.Identifier, True),
            ("location", "location", fhirreference.FHIRReference, False),
            ("notAvailable", "notAvailable", HealthcareServiceNotAvailable, True),
            ("photo", "photo", attachment.Attachment, False),
            ("programName", "programName", str, True),
            ("providedBy", "providedBy", fhirreference.FHIRReference, False),
            ("publicKey", "publicKey", str, False),
            ("referralMethod", "referralMethod", codeableconcept.CodeableConcept, True),
            ("serviceCategory", "serviceCategory", codeableconcept.CodeableConcept, False),
            ("serviceName", "serviceName", str, False),
            ("serviceProvisionCode", "serviceProvisionCode", codeableconcept.CodeableConcept, True),
            ("serviceType", "serviceType", HealthcareServiceServiceType, True),
            ("telecom", "telecom", contactpoint.ContactPoint, True),
        ])
        return js


class HealthcareServiceAvailableTime(fhirelement.FHIRElement):
    """ A Collection of times that the Service Site is available.
    """
    
    resource_name = "HealthcareServiceAvailableTime"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.allDay = None
        """ Is this always available? (hence times are irrelevant) e.g. 24 hour
        service.
        Type `bool`. """
        
        self.availableEndTime = None
        """ The closing time of day. Note: If the AllDay flag is set, then this
        time is ignored.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.availableStartTime = None
        """ The opening time of day. Note: If the AllDay flag is set, then this
        time is ignored.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.daysOfWeek = None
        """ mon | tue | wed | thu | fri | sat | sun.
        List of `str` items. """
        
        super(HealthcareServiceAvailableTime, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(HealthcareServiceAvailableTime, self).elementProperties()
        js.extend([
            ("allDay", "allDay", bool, False),
            ("availableEndTime", "availableEndTime", fhirdate.FHIRDate, False),
            ("availableStartTime", "availableStartTime", fhirdate.FHIRDate, False),
            ("daysOfWeek", "daysOfWeek", str, True),
        ])
        return js


class HealthcareServiceNotAvailable(fhirelement.FHIRElement):
    """ The HealthcareService is not available during this period of time due to
    the provided reason.
    """
    
    resource_name = "HealthcareServiceNotAvailable"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.description = None
        """ The reason that can be presented to the user as to why this time is
        not available.
        Type `str`. """
        
        self.during = None
        """ Service is not available (seasonally or for a public holiday) from
        this date.
        Type `Period` (represented as `dict` in JSON). """
        
        super(HealthcareServiceNotAvailable, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(HealthcareServiceNotAvailable, self).elementProperties()
        js.extend([
            ("description", "description", str, False),
            ("during", "during", period.Period, False),
        ])
        return js


class HealthcareServiceServiceType(fhirelement.FHIRElement):
    """ A specific type of service that may be delivered or performed.
    """
    
    resource_name = "HealthcareServiceServiceType"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.specialty = None
        """ Collection of Specialties handled by the Service Site. This is more
        of a Medical Term.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.type = None
        """ The specific type of service being delivered or performed.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(HealthcareServiceServiceType, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(HealthcareServiceServiceType, self).elementProperties()
        js.extend([
            ("specialty", "specialty", codeableconcept.CodeableConcept, True),
            ("type", "type", codeableconcept.CodeableConcept, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import medicationdispense
from .fhirdate import FHIRDate


class MedicationDispenseTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("MedicationDispense", js["resourceType"])
        return medicationdispense.MedicationDispense(js)
    
    def testMedicationDispense1(self):
        inst = self.instantiate_from("medicationdispense-qicore-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a MedicationDispense instance")
        self.implMedicationDispense1(inst)
        
        js = inst.as_json()
        self.assertEqual("MedicationDispense", js["resourceType"])
        inst2 = medicationdispense.MedicationDispense(js)
        self.implMedicationDispense1(inst2)
    
    def implMedicationDispense1(self, inst):
        self.assertEqual(inst.dosageInstruction[0].doseQuantity.code, "ml")
        self.assertEqual(inst.dosageInstruction[0].doseQuantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.dosageInstruction[0].doseQuantity.units, "ml")
        self.assertEqual(inst.dosageInstruction[0].doseQuantity.value, 5)
        self.assertEqual(inst.dosageInstruction[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/pharmacy-core-doseType")
        self.assertEqual(inst.dosageInstruction[0].extension[0].valueCodeableConcept.coding[0].code, "440231000124106")
        self.assertEqual(inst.dosageInstruction[0].extension[0].valueCodeableConcept.coding[0].display, "Maintenance dose")
        self.assertEqual(inst.dosageInstruction[0].extension[0].valueCodeableConcept.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.dosageInstruction[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/pharmacy-core-infuseOver")
        self.assertEqual(inst.dosageInstruction[0].extension[1].valueQuantity.code, "m")
        self.assertEqual(inst.dosageInstruction[0].extension[1].valueQuantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.dosageInstruction[0].extension[1].valueQuantity.units, "min")
        self.assertEqual(inst.dosageInstruction[0].extension[1].valueQuantity.value, 1)
        self.assertEqual(inst.dosageInstruction[0].extension[2].url, "http://hl7.org/fhir/StructureDefinition/pharmacy-core-minDosePerPeriod")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.denominator.code, "day")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.denominator.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.denominator.units, "day")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.denominator.value, 1)
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.numerator.code, "ml")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.numerator.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.numerator.units, "ml")
        self.assertEqual(inst.dosageInstruction[0].extension[2].valueRatio.numerator.value, 15)
        self.assertEqual(inst.dosageInstruction[0].extension[3].url, "http://hl7.org/fhir/StructureDefinition/pharmacy-core-maxDeliveryVolume")
        self.assertEqual(inst.dosageInstruction[0].extension[3].valueQuantity.code, "ml")
        self.assertEqual(inst.dosageInstruction[0].extension[3].valueQuantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.dosageInstruction[0].extension[3].valueQuantity.units, "ml")
        self.assertEqual(inst.dosageInstruction[0].extension[3].valueQuantity.value, 15)
        self.assertEqual(inst.dosageInstruction[0].route.coding[0].code, "394899003")
        self.assertEqual(inst.dosageInstruction[0].route.coding[0].display, "oral administration of treatment")
        self.assertEqual(inst.dosageInstruction[0].route.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.dosageInstruction[0].scheduleTiming.repeat.frequency, 3)
        self.assertEqual(inst.dosageInstruction[0].scheduleTiming.repeat.period, 1)
        self.assertEqual(inst.dosageInstruction[0].scheduleTiming.repeat.periodUnits, "d")
        self.assertEqual(inst.extension[0].url, "http://hl7.org/fhir/StructureDefinition/pharmacy-core-refillsRemaining")
        self.assertEqual(inst.extension[0].valueInteger, 0)
        self.assertEqual(inst.extension[1].url, "http://hl7.org/fhir/StructureDefinition/medicationdispense-validityPeriod")
        self.assertEqual(inst.extension[1].valuePeriod.end.date, FHIRDate("2012-06-10").date)
        self.assertEqual(inst.extension[1].valuePeriod.end.as_json(), "2012-06-10")
        self.assertEqual(inst.extension[1].valuePeriod.start.date, FHIRDate("2012-05-30").date)
        self.assertEqual(inst.extension[1].valuePeriod.start.as_json(), "2012-05-30")
        self.assertEqual(inst.id, "qicore")
        self.assertEqual(inst.quantity.code, "ml")
        self.assertEqual(inst.quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.quantity.units, "ml")
        self.assertEqual(inst.quantity.value, 100)
        self.assertEqual(inst.status, "completed")
        self.assertEqual(inst.substitution.type.coding[0].code, "NoSub")
        self.assertEqual(inst.substitution.type.coding[0].display, "No substitution made or expected")
        self.assertEqual(inst.substitution.type.coding[0].system, "http://example.org/MedDispSubType")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.whenHandedOver.date, FHIRDate("2012-05-31T10:20:00+00:00").date)
        self.assertEqual(inst.whenHandedOver.as_json(), "2012-05-31T10:20:00+00:00")
        self.assertEqual(inst.whenPrepared.date, FHIRDate("2012-05-30T16:20:00+00:00").date)
        self.assertEqual(inst.whenPrepared.as_json(), "2012-05-30T16:20:00+00:00")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import supply
from .fhirdate import FHIRDate


class SupplyTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Supply", js["resourceType"])
        return supply.Supply(js)
    
    def testSupply1(self):
        inst = self.instantiate_from("supply-example1.json")
        self.assertIsNotNone(inst, "Must have instantiated a Supply instance")
        self.implSupply1(inst)
        
        js = inst.as_json()
        self.assertEqual("Supply", js["resourceType"])
        inst2 = supply.Supply(js)
        self.implSupply1(inst2)
    
    def implSupply1(self, inst):
        self.assertEqual(inst.dispense[0].identifier.system, "http://example.org/MM-Supply-Application")
        self.assertEqual(inst.dispense[0].identifier.use, "usual")
        self.assertEqual(inst.dispense[0].identifier.value, "12345")
        self.assertEqual(inst.dispense[0].quantity.code, "{each}")
        self.assertEqual(inst.dispense[0].quantity.system, "http://unitsofmeasure.org/")
        self.assertEqual(inst.dispense[0].quantity.units, "EA")
        self.assertEqual(inst.dispense[0].quantity.value, 1)
        self.assertEqual(inst.dispense[0].status, "dispensed")
        self.assertEqual(inst.dispense[0].type.coding[0].code, "device")
        self.assertEqual(inst.dispense[0].type.coding[0].display, "Device")
        self.assertTrue(inst.dispense[0].type.coding[0].primary)
        self.assertEqual(inst.dispense[0].type.coding[0].system, "http://hl7.org/fhir/supply-item-type")
        self.assertEqual(inst.dispense[0].whenHandedOver.date, FHIRDate("2014-12-06T15:42:15-08:00").date)
        self.assertEqual(inst.dispense[0].whenHandedOver.as_json(), "2014-12-06T15:42:15-08:00")
        self.assertEqual(inst.id, "102")
        self.assertEqual(inst.identifier.system, "http://example.org/OR-Supply-Application")
        self.assertEqual(inst.identifier.value, "23455")
        self.assertEqual(inst.kind.coding[0].code, "central")
        self.assertEqual(inst.kind.coding[0].display, "Central Supply")
        self.assertTrue(inst.kind.coding[0].primary)
        self.assertEqual(inst.kind.coding[0].system, "http://hl7.org/fhir/supply-type")
        self.assertEqual(inst.status, "received")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/NutritionOrder) on 2015-07-06.
#  2015, SMART Health IT.


from . import codeableconcept
from . import domainresource
from . import fhirdate
from . import fhirelement
from . import fhirreference
from . import identifier
from . import quantity
from . import ratio
from . import timing


class NutritionOrder(domainresource.DomainResource):
    """ A request for a diet, formula or nutritional supplement.
    
    A request to supply a diet, formula feeding (enteral) or oral nutritional
    supplement to a patient/resident.
    """
    
    resource_name = "NutritionOrder"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.allergyIntolerance = None
        """ List of the patient's food and nutrition-related allergies and
        intolerances.
        List of `FHIRReference` items referencing `AllergyIntolerance` (represented as `dict` in JSON). """
        
        self.dateTime = None
        """ Date and time the nutrition order was requested.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.encounter = None
        """ The encounter associated with that this nutrition order.
        Type `FHIRReference` referencing `Encounter` (represented as `dict` in JSON). """
        
        self.enteralFormula = None
        """ Enteral formula components.
        Type `NutritionOrderEnteralFormula` (represented as `dict` in JSON). """
        
        self.excludeFoodModifier = None
        """ Order-specific modifier about the type of food that should not be
        given.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.foodPreferenceModifier = None
        """ Order-specific modifier about the type of food that should be given.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Identifiers assigned to this order.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.oralDiet = None
        """ Oral diet components.
        Type `NutritionOrderOralDiet` (represented as `dict` in JSON). """
        
        self.orderer = None
        """ Who ordered the diet, formula or nutritional supplement.
        Type `FHIRReference` referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.patient = None
        """ The person who requires the diet, formula or nutritional supplement.
        Type `FHIRReference` referencing `Patient` (represented as `dict` in JSON). """
        
        self.status = None
        """ proposed | draft | planned | requested | active | on-hold |
        completed | cancelled.
        Type `str`. """
        
        self.supplement = None
        """ Supplement components.
        List of `NutritionOrderSupplement` items (represented as `dict` in JSON). """
        
        super(NutritionOrder, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(NutritionOrder, self).elementProperties()
        js.extend([
            ("allergyIntolerance", "allergyIntolerance", fhirreference.FHIRReference, True),
            ("dateTime", "dateTime", fhirdate.FHIRDate, False),
            ("encounter", "encounter", fhirreference.FHIRReference, False),
            ("enteralFormula", "enteralFormula", NutritionOrderEnteralFormula, False),
            ("excludeFoodModifier", "excludeFoodModifier", codeableconcept.CodeableConcept, True),
            ("foodPreferenceModifier", "foodPreferenceModifier", codeableconcept.CodeableConcept, True),
            ("identifier", "identifier", identifier.Identifier, True),
            ("oralDiet", "oralDiet", NutritionOrderOralDiet, False),
            ("orderer", "orderer", fhirreference.FHIRReference, False),
            ("patient", "patient", fhirreference.FHIRReference, False),
            ("status", "status", str, False),
            ("supplement", "supplement", NutritionOrderSupplement, True),
        ])
        return js


class NutritionOrderEnteralFormula(fhirelement.FHIRElement):
    """ Enteral formula components.
    
    Feeding provided through the gastrointestinal tract via a tube, catheter,
    or stoma that delivers nutrition distal to the oral cavity.
    """
    
    resource_name = "NutritionOrderEnteralFormula"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.additiveProductName = None
        """ Product or brand name of the modular additive.
        Type `str`. """
        
        self.additiveType = None
        """ Type of modular component to add to the feeding.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.administrationInstructions = None
        """ Formula feeding instructions expressed as text.
        Type `str`. """
        
        self.baseFormulaProductName = None
        """ Product or brand name of the enteral or infant formula.
        Type `str`. """
        
        self.baseFormulaType = None
        """ Type of enteral or infant formula.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.caloricDensity = None
        """ Amount of energy per specified volume that is required.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.maxVolumeToDeliver = None
        """ Upper limit on formula volume per unit of time.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.quantity = None
        """ The volume of formula to provide.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.rate = None
        """ Speed with which the formula is provided per period of time.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.rateAdjustment = None
        """ Change in the rate of administration over a given time.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.routeofAdministration = None
        """ How the formula should enter the patient's gastrointestinal tract.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.scheduled = None
        """ Scheduled frequency of enteral feeding.
        Type `Timing` (represented as `dict` in JSON). """
        
        super(NutritionOrderEnteralFormula, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(NutritionOrderEnteralFormula, self).elementProperties()
        js.extend([
            ("additiveProductName", "additiveProductName", str, False),
            ("additiveType", "additiveType", codeableconcept.CodeableConcept, False),
            ("administrationInstructions", "administrationInstructions", str, False),
            ("baseFormulaProductName", "baseFormulaProductName", str, False),
            ("baseFormulaType", "baseFormulaType", codeableconcept.CodeableConcept, False),
            ("caloricDensity", "caloricDensity", quantity.Quantity, False),
            ("maxVolumeToDeliver", "maxVolumeToDeliver", quantity.Quantity, False),
            ("quantity", "quantity", quantity.Quantity, False),
            ("rate", "rate", ratio.Ratio, False),
            ("rateAdjustment", "rateAdjustment", quantity.Quantity, False),
            ("routeofAdministration", "routeofAdministration", codeableconcept.CodeableConcept, False),
            ("scheduled", "scheduled", timing.Timing, False),
        ])
        return js


class NutritionOrderOralDiet(fhirelement.FHIRElement):
    """ Oral diet components.
    
    Diet given orally in contrast to enteral (tube) feeding.
    """
    
    resource_name = "NutritionOrderOralDiet"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.fluidConsistencyType = None
        """ The required consistency of fluids and liquids provided to the
        patient.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.instruction = None
        """ Instructions or additional information about the oral diet.
        Type `str`. """
        
        self.nutrient = None
        """ Required  nutrient modifications.
        List of `NutritionOrderOralDietNutrient` items (represented as `dict` in JSON). """
        
        self.scheduled = None
        """ Scheduled frequency of diet.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.texture = None
        """ Required  texture modifications.
        List of `NutritionOrderOralDietTexture` items (represented as `dict` in JSON). """
        
        self.type = None
        """ Type of oral diet or diet restrictions that describe what can be
        consumed orally.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        super(NutritionOrderOralDiet, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(NutritionOrderOralDiet, self).elementProperties()
        js.extend([
            ("fluidConsistencyType", "fluidConsistencyType", codeableconcept.CodeableConcept, True),
            ("instruction", "instruction", str, False),
            ("nutrient", "nutrient", NutritionOrderOralDietNutrient, True),
            ("scheduled", "scheduled", timing.Timing, False),
            ("texture", "texture", NutritionOrderOralDietTexture, True),
            ("type", "type", codeableconcept.CodeableConcept, True),
        ])
        return js


class NutritionOrderOralDietNutrient(fhirelement.FHIRElement):
    """ Required  nutrient modifications.
    
    Class that defines the quantity and type of nutrient modifications required
    for the oral diet.
    """
    
    resource_name = "NutritionOrderOralDietNutrient"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.amount = None
        """ Quantity of the specified nutrient.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.mod = None
        """ Type of nutrient that is being modified.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(NutritionOrderOralDietNutrient, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(NutritionOrderOralDietNutrient, self).elementProperties()
        js.extend([
            ("amount", "amount", quantity.Quantity, False),
            ("mod", "modifier", codeableconcept.CodeableConcept, False),
        ])
        return js


class NutritionOrderOralDietTexture(fhirelement.FHIRElement):
    """ Required  texture modifications.
    
    Class that describes any texture modifications required for the patient to
    safely consume various types of solid foods.
    """
    
    resource_name = "NutritionOrderOralDietTexture"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.foodType = None
        """ Concepts that are used to identify an entity that is ingested for
        nutritional purposes.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.mod = None
        """ Code to indicate how to alter the texture of the foods, e.g.,
        pureed.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(NutritionOrderOralDietTexture, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(NutritionOrderOralDietTexture, self).elementProperties()
        js.extend([
            ("foodType", "foodType", codeableconcept.CodeableConcept, False),
            ("mod", "modifier", codeableconcept.CodeableConcept, False),
        ])
        return js


class NutritionOrderSupplement(fhirelement.FHIRElement):
    """ Supplement components.
    
    Oral nutritional products given in order to add further nutritional value
    to the patient's diet.
    """
    
    resource_name = "NutritionOrderSupplement"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.instruction = None
        """ Instructions or additional information about the oral supplement.
        Type `str`. """
        
        self.productName = None
        """ Product or brand name of the nutritional supplement.
        Type `str`. """
        
        self.quantity = None
        """ Amount of the nutritional supplement.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.scheduled = None
        """ Scheduled frequency of supplement.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.type = None
        """ Type of supplement product requested.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(NutritionOrderSupplement, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(NutritionOrderSupplement, self).elementProperties()
        js.extend([
            ("instruction", "instruction", str, False),
            ("productName", "productName", str, False),
            ("quantity", "quantity", quantity.Quantity, False),
            ("scheduled", "scheduled", timing.Timing, False),
            ("type", "type", codeableconcept.CodeableConcept, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import procedurerequest
from .fhirdate import FHIRDate


class ProcedureRequestTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ProcedureRequest", js["resourceType"])
        return procedurerequest.ProcedureRequest(js)
    
    def testProcedureRequest1(self):
        inst = self.instantiate_from("procedurerequest-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest1(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest1(inst2)
    
    def implProcedureRequest1(self, inst):
        self.assertEqual(inst.id, "example")
        self.assertEqual(inst.text.div, "<div>To be added</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "323418000")
        self.assertEqual(inst.type.coding[0].display, "Fix me up")
        self.assertEqual(inst.type.coding[0].system, "http://snomed.info/sct")
    
    def testProcedureRequest2(self):
        inst = self.instantiate_from("procedurerequest-qicore-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest2(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest2(inst2)
    
    def implProcedureRequest2(self, inst):
        self.assertEqual(inst.bodySite[0].siteCodeableConcept.coding[0].code, "66754008")
        self.assertEqual(inst.bodySite[0].siteCodeableConcept.coding[0].display, "Appendix structure")
        self.assertEqual(inst.bodySite[0].siteCodeableConcept.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.extension[0].url, "http://hl7.org/fhir/StructureDefinition/procedurerequest-authorizedBy")
        self.assertEqual(inst.id, "qicore")
        self.assertEqual(inst.indication[0].coding[0].code, "163220003")
        self.assertEqual(inst.indication[0].coding[0].display, "On examination - abdominal pain - right iliac")
        self.assertEqual(inst.indication[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.orderedOn.date, FHIRDate("2013-04-04").date)
        self.assertEqual(inst.orderedOn.as_json(), "2013-04-04")
        self.assertEqual(inst.priority, "urgent")
        self.assertEqual(inst.status, "completed")
        self.assertEqual(inst.text.div, "<div>Request for Routine Appendectomy</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.timingDateTime.date, FHIRDate("2013-04-05").date)
        self.assertEqual(inst.timingDateTime.as_json(), "2013-04-05")
        self.assertEqual(inst.type.coding[0].code, "80146002")
        self.assertEqual(inst.type.coding[0].display, "Appendectomy (Procedure)")
        self.assertEqual(inst.type.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.type.text, "Appendectomy")

